Module graphml

Module graphml 

Functions

export
Export the GraphML file without any guarantuee on the order of the XML elements.
export_stable_order
Export the GraphML file and ensure a stable order of the XML elements.
files_for_corpus
A corpus can consist of several GraphML-files if the corpus is partitioned and there is a subdirectory with the same name as the basename of the GraphML file given as argument.
import
Import a single GraphML-file as an annotation Graph.
read_graphml
Read in a single GraphML file from input and fill the updates given as parameters.